@@ -20,8 +20,9 @@
 #include "ui_diagrampropertiespage.h"
 
 class ClassOptionsPage;
+class UMLScene;
 class UMLView;
-class UMLWidgetColorPage;
+class UMLWidgetStylePage;
 class KFontChooser;
 
 /**
@@ -39,7 +40,7 @@ class UMLViewDialog : public KPageDialog
 {
     Q_OBJECT
 public:
-    UMLViewDialog(QWidget * pParent, UMLView * pView);
+    UMLViewDialog(QWidget * pParent, UMLScene * pScene);
     ~UMLViewDialog();
 
 protected:
@@ -47,20 +48,20 @@ protected:
 
     void setupDiagramPropertiesPage();
     void setupClassPage();
-    void setupColorPage();
+    void setupStylePage();
     void setupFontPage();
 
     void applyPage( KPageWidgetItem* );
 
     void checkName();
 
-    UMLView*               m_pView;   ///< the view to represent
+    UMLScene*              m_pScene;  ///< the scene to represent
     Settings::OptionState  m_options;
     KFontChooser*          m_pChooser;
     DiagramPropertiesPage* m_diagramProperties;
     ClassOptionsPage*      m_pOptionsPage;
-    UMLWidgetColorPage*    m_pColorPage;
-    KPageWidgetItem*       m_pageColorItem;
+    UMLWidgetStylePage*    m_pStylePage;
+    KPageWidgetItem*       m_pageStyleItem;
     KPageWidgetItem*       m_pageFontItem;
     KPageWidgetItem*       m_pageDisplayItem;
     KPageWidgetItem*       m_pageGeneralItem;
