@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2006                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -38,10 +38,7 @@ public:
 
 protected:
     UMLSceneSize minimumSize();
-    /**
-     * The right mouse button menu
-     */
-    ListPopupMenu* m_pMenu;
+
 };
 
 #endif
