@@ -39,6 +39,10 @@
 #include <QtGui/QPainter>
 #include <QtGui/QValidator>
 
+
+const UMLSceneValue FloatingTextWidget::restrictPositionMin = 0;
+const UMLSceneValue FloatingTextWidget::restrictPositionMax = 3000;
+
 /**
  * Constructs a FloatingTextWidget instance.
  *
@@ -99,7 +103,7 @@ void FloatingTextWidget::setText(const QString &t)
         QString seqNum, op;
         m_linkWidget->seqNumAndOp(seqNum, op);
         if (seqNum.length() > 0 || op.length() > 0) {
-            if (! m_scene->getShowOpSig())
+            if (! m_scene->showOpSig())
                 op.replace( QRegExp("\\(.*\\)"), "()" );
             m_Text = seqNum.append(": ").append( op );
         }
@@ -180,7 +184,7 @@ void FloatingTextWidget::setTextcmd(const QString &t)
 void FloatingTextWidget::showChangeTextDialog()
 {
     bool ok = false;
-    QString newText = KInputDialog::getText(i18n("Change Text"), i18n("Enter new text:"), text(), &ok, m_scene);
+    QString newText = KInputDialog::getText(i18n("Change Text"), i18n("Enter new text:"), text(), &ok, m_scene->view());
 
     if (ok && newText != text() && isTextValid(newText)) {
         setText(newText);
@@ -208,7 +212,7 @@ void FloatingTextWidget::showOperationDialog()
         return;
     }
 
-    QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene, c);
+    QPointer<SelectOpDlg> selectDlg = new SelectOpDlg(m_scene->view(), c);
     selectDlg->setSeqNumber(seqNum);
     if (m_linkWidget->operation() == 0) {
         selectDlg->setCustomOp(opText);
@@ -373,7 +377,7 @@ void FloatingTextWidget::handleRename()
         t = i18n("ERROR");
     }
     bool ok = false;
-    QString newText = KInputDialog::getText(i18n("Rename"), t, text(), &ok, m_scene, &v);
+    QString newText = KInputDialog::getText(i18n("Rename"), t, text(), &ok, m_scene->view(), &v);
     if (!ok || newText == text()) {
         return;
     }
@@ -465,8 +469,7 @@ void FloatingTextWidget::paint(QPainter & p, int offsetX, int offsetY)
     int w = width();
     int h = height();
     p.setFont( UMLWidget::font() );
-    QColor textColor(50, 50, 50);
-    p.setPen(textColor);
+    p.setPen(textColor());
     p.drawText( offsetX, offsetY,w,h, Qt::AlignCenter, displayText() );
     if(m_selected)
         drawSelected(&p, offsetX, offsetY);
@@ -547,7 +550,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
                 bool ok = false;
                 QString opText = KInputDialog::getText(i18nc("operation name", "Name"),
                                                        i18n("Enter operation name:"),
-                                                       text(), &ok, m_scene);
+                                                       text(), &ok, m_scene->view());
                 if (ok)
                     m_linkWidget->setCustomOpText(opText);
                 return;
@@ -571,7 +574,7 @@ void FloatingTextWidget::slotMenuSelection(QAction* action)
     case ListPopupMenu::mt_Change_Font:
         {
             QFont fnt = font();
-            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene) ) {
+            if(KFontDialog::getFont(fnt, KFontChooser::NoDisplayFlags, m_scene->view()) ) {
                 if(m_textRole == Uml::TextRole::Floating || m_textRole == Uml::TextRole::Seq_Message) {
                     setFont(fnt);
                 } else if (m_linkWidget) {
